checkRequire("Lua_ArtifactSkillItem");
Lua_LineupOverviewWindow = class("Lua_LineupOverviewWindow", Lua_Window)
function Lua_LineupOverviewWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_LineupOverviewWindow";
	self.skinName = "LineupOverviewWindow_skin";
	self.showBlackMask = true;
end

function Lua_LineupOverviewWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.itemList = Array();

	self.btnCancel:addClickFuntion(self, self.hide);
	self.btnSure:addClickFuntion(self, self.onSure);
end

function Lua_LineupOverviewWindow:dispose()
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_LineupOverviewWindow:showWin(param)
	self:superCall("showWin", param);

	local vo = DataCenter.heroLineupData:getLineupVo(param);
	local arr = Array();
	for i = 1, vo.team_number do
		arr:add(i);
	end
	arr:sortf(self, self.onForceSortFun);

	local item;
	local index;
	for i = 1, vo.team_number do
		item = self.itemList[i];
		if item == nil then
			item = Lua_LineupOverviewItem.new(self.content);
			self.itemList:add(item);
		end
		item:setLocation(0, 219 - (i - 1) * 204, 0);

		index = arr[i];
		item:setIndex(i);
		item:setArtifact(vo:getArtifactArr(index));
		item:setHero(param, vo:getHeroArr(index));
	end
end

function Lua_LineupOverviewWindow:onForceSortFun(a, b)
	local a_force = DataCenter.heroLineupData:calcLineupForce(self.showData, a);
	local b_force = DataCenter.heroLineupData:calcLineupForce(self.showData, b);
	if a_force < b_force then
		return false;
	end
	return true;
end

function Lua_LineupOverviewWindow:onSure(go)
	Lua_MsgUtil.callFunc("LINEUP_OVERVIEW_COMPLETE", true);
	self:hide();
end










Lua_LineupOverviewItem = class("Lua_LineupOverviewItem", Lua_DisplayObject)
function Lua_LineupOverviewItem:ctor(p)
	self:superCall("ctor", p, "LineupOverviewItem_skin");
end

function Lua_LineupOverviewItem:buildShowItem()
	self:superCall("buildShowItem");

	self.artifactArr = Array();
	self.heroArr = Array();
	local item;
	for i = 1, 6 do
		item = Lua_ItemIcon.new(self.content);
		item:setScale(0.7, 0.7, 1);
		item:setLocation(-255 + (i - 1) * 95, -30, 0);
		self.heroArr:add(item);
	end
end

function Lua_LineupOverviewItem:dispose()
	if self.artifactArr then
		self.artifactArr:dispose();
		self.artifactArr = nil;
	end
	if self.heroArr then
		self.heroArr:dispose();
		self.heroArr = nil;
	end
	self:superCall("dispose");
end

function Lua_LineupOverviewItem:setIndex(idx)
	self.totalForce = 0;
	self.titleText.text = LanUtil.formateStr(126331, tostring(idx));
end

function Lua_LineupOverviewItem:setArtifact(data)
	local item;
	local vo;
	for i = 1, data:getSize() do
		item = self.artifactArr[idx];
		if item == nil then
			item = Lua_ArtifactSkillItem.new(self.content);
			item:setScale(0.72, 0.72, 1);
			self.artifactArr:add(item);
		end
		item:setLocation(150 + (i - 1) * 60, 60, 0);
		if data[i] == 0 then
			item:setSkillId(0);
		else
			vo = DataCenter.artifactData:getArtifactVoById(data[i]);
			item:setSkillId(vo.skill_id);
			self.totalForce = DataCenter.roleData.leaderForce;
		end
		item:hideLevel();
		item:hideEnergy();
	end
end

function Lua_LineupOverviewItem:setHero(lineupType, data)
	local arr = Array();
	for i = 1, data:getSize() do
		if data[i] > 0 then
			arr:add(data[i]);
		end
	end
	local dataLen = arr:getSize();
	local vo;
	local force = 0;
	for i = 1, dataLen do
		vo = DataCenter.heroLineupData:getHeroVo(lineupType, arr[i]);
		force = force + vo.heroForce;
		self.heroArr[i]:setData(vo);
	end
	self.forceText.text = self.totalForce + force;
end