checkRequire("Lua_HeroLineupWindow");
Lua_GodSeaPeakLineupWindow = class("Lua_GodSeaPeakLineupWindow", Lua_HeroLineupWindow)
function Lua_GodSeaPeakLineupWindow:ctor()
	self:superCall("ctor");
	self.windowName = "Lua_GodSeaPeakLineupWindow";
end

function Lua_GodSeaPeakLineupWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.hideLineupNum = DataCenter.godSeaPeakUtil:getHideLineupNum(DataCenter.godSeaPeakData.curRank);
	local list = DataCenter.godSeaPeakData.hideLineupList;
	self.hideLineupDic = {};
	if list then
		for i,v in ipairs(list) do
			self.hideLineupDic[v] = 1;
		end
	end

	self.promptBg = UICreate.createUIAtlasImage(self.topObject, "god_sea_peak_atlas_1", "xui_shzd_widget_44", -211, -150, 0, 0);
	self.promptBg.anchorValue = 1;

	self.promptText = UICreate.createLabel(self.topObject, nil, -350, -150, 100, 31, 22);
	self.promptText.anchorValue = 1;
	self.promptText.pivotValue = 3;
	self.promptText.alignmentValue = 3;
	self.promptText.horizontalOverflowValue = 1;
end

function Lua_GodSeaPeakLineupWindow:updateShowInfo(param)
	if type(param) == type_str_table then
		self.lineupType = param.lineupType;
		self.lineupIdx = param.lineupIdx;
	elseif type(param) == type_str_number then
		self.lineupType = param;
	end
	self:showSceneByLineupType(self.lineupType);
	self:updateLineupInfo();
	self:createTeamButton(self.data.team_number);
	self.campSiftPanel:setSelected(self.defaultCamp, 0, true);

	local limitNum = self.data:getLineupLimitNum(self.lineupIdx);
	self.promptText.text = LanUtil.formateStr(126341, tostring(limitNum));
	if self.lineupType == 60 and self.hideLineupNum > 0 then
		self.cbHideLineup = UICreate.createCheckBox(self.bottomObject, nil, 150, 545, 0, 0);
		self.cbHideLineup.txt.fontName = Lua_MyUISettings.defaultFontName;
		self.cbHideLineup.txt.fontSize = 22;
		self.cbHideLineup.txt.colorStr = Lua_ColorDefine.transColorStr("D8D8D8");
		self.cbHideLineup.txt.effectStyle = 2;
		self.cbHideLineup.txt.effectColorStr = Lua_ColorDefine.transColor("000000");
		self.cbHideLineup.txt:setEffectDistance(2, 2);
		self.cbHideLineup:setLangValue(126342);
		self.cbHideLineup:addBoxChange(self, self.onHideLineup);
		self.cbHideLineup.selected = (self.hideLineupDic[self.lineupIdx] == 1);
	end
end

function Lua_GodSeaPeakLineupWindow:onHeroSelected(heroVo)
	local lineupIdx = self.data:getHeroLineupIdx(heroVo.id)
	if lineupIdx and lineupIdx > 0 and lineupIdx ~= self.lineupIdx then
		if self.heroNum >= self.data:getLineupLimitNum(self.lineupIdx) then
			OperateAlert.showLangValue(126300)
			return
		end

		self.modifyHeroVo = self.data:getHeroVoById(heroVo.id)
		if self.modifyHeroVo then
			local tipsData = { des = LanUtil.formateStr(126340, tostring(lineupIdx)), btnType = 1, owner = self, sureFun = self.onModifyLineupIdx }
			Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData)
			return
		end
	end

	local standIdx = self.data:getHeroStandIdx(heroVo.unique_id)
	if standIdx == nil then -- 未上阵
		if self.heroNum >= self.data:getLineupLimitNum(self.lineupIdx) then
			OperateAlert.showLangValue(126300)
			return
		end

		standIdx = DataCenter.heroLineupData:getNullStandIdx(self.standType, self.heroDic, self.lineupIdx)
		if standIdx == nil then -- 上阵英雄已达上限
			OperateAlert.showLangValue(126300)
			return
		end

		if lineupIdx and lineupIdx == self.lineupIdx then
			OperateAlert.showLangValue(126302)
			return
		end

		self.data:setHeroById(self.lineupIdx, standIdx, heroVo.unique_id)
	else
		if lineupIdx ~= self.lineupIdx and lineupIdx > self.lineupNum then
			local nullIdx = DataCenter.heroLineupData:getNullStandIdx(self.standType, self.heroDic, self.lineupIdx)
			if nullIdx == nil then -- 上阵英雄已达上限
				OperateAlert.showLangValue(126300)
				return
			end

			-- 卸下原来所在队伍，上阵当前队伍
			self.data:setHeroById(lineupIdx, standIdx, 0)
			self.data:setHeroById(self.lineupIdx, nullIdx, heroVo.unique_id)
		else
			self.data:setHeroById(self.lineupIdx, standIdx, 0)
		end
	end

	self:updateHeroSelected();
	self:updateSceneModel();
	self:updateLineupNum();
	self:updateAureoleInfo();
end

function Lua_GodSeaPeakLineupWindow:onTeamSelected(lineupIdx, bUpdate)
	self:superCall("onTeamSelected", lineupIdx, bUpdate);
	local limitNum = self.data:getLineupLimitNum(self.lineupIdx);
	self.promptText.text = LanUtil.formateStr(126341, tostring(limitNum));
	if self.lineupType == 60 and self.hideLineupNum > 0 then
		self.cbHideLineup.selected = (self.hideLineupDic[self.lineupIdx] == 1);
	end
end

function Lua_GodSeaPeakLineupWindow:onBtnSaveClick()
	if self.isHideLineup == true and self.lineupType == 60 and self.hideLineupNum > 0 then
		Lua_ProxyManager.getProxy("Lua_GodSeaPeakProxy"):sHideLineup(self.hideLineupDic);
		self.isHideLineup = false;
	end

	if DataCenter.heroLineupData:checkLineupIsNull(59) then
		Lua_ProxyManager.getProxy("Lua_HeroProxy"):sHeroSaveLineup(59, self.data);
	end

	self:superCall("onBtnSaveClick");
end

function Lua_GodSeaPeakLineupWindow:onHideLineup(bValue)
	self.isHideLineup = true;
	if bValue then
		local num = 0;
		for k,v in pairs(self.hideLineupDic) do
			if v == 1 then
				num = num + 1;
			end
		end
		if num >= self.hideLineupNum then
			self.cbHideLineup.selected = false;
			OperateAlert.show(LanUtil.formateStr(790021, tostring(self.hideLineupNum)));
		else
			self.hideLineupDic[self.lineupIdx] = 1;
		end
	else
		self.hideLineupDic[self.lineupIdx] = nil;
	end
end