checkRequire("Lua_FightLineupWindow");
checkRequire("Lua_WildLodeLineupCell");
Lua_WildLodeAttackLineupWindow = class("Lua_WildLodeAttackLineupWindow", Lua_FightLineupWindow)
function Lua_WildLodeAttackLineupWindow:ctor()
	self:superCall("ctor");
	self.windowName = "Lua_WildLodeAttackLineupWindow";
end

function Lua_WildLodeAttackLineupWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("WILD_SECRET_LODE_FIGHT_CHECK", self, self.onFightCheck);

	self.heroList:setListCell(Lua_WildLodeLineupCell, 107, 107, 5);
end

function Lua_WildLodeAttackLineupWindow:updateShowInfo(param)
	self.template_id = param.templateId;
	self.lineupType = param.lineupType;
	self.replaceNum = param.param2;

	local data = param.param1;
	self.stage_id = data.mine_site_info.mine_site_id;
	self.lineup = data.lineup;
	self.player_id = tonumber(data.show_role.id);

	self:showSceneByTemplateId(self.template_id);
	self:updateLineupInfo();

	self:createTeamButton(self.data.team_number);
	self.campSiftPanel:setSelected(self.defaultCamp, 0);

	self.defenderItem:setName(data.show_role.name);
	self:updateEnemyInfo();
end

function Lua_WildLodeAttackLineupWindow:showSceneByTemplateId(templateId)
	if templateId == nil then
		return;
	end

	if self.sceneDic == nil then
		self.sceneDic = {};
	end
	local sceneId = DataCenter.wildSecretData:getLodeFightSceneId(self.stage_id);
	if sceneId == 0 then
		sceneId = DataCenter.heroLineupData:getFightLineupSceneId(templateId);
	end
	self.sceneDic[sceneId] = 1;
	self:setWinSceneId(sceneId);
end

function Lua_WildLodeAttackLineupWindow:updateEnemyInfo()
	local force;
	local heroList;
	if self.lineup and #self.lineup >= self.lineupIdx then
		force = self.lineup[self.lineupIdx].force;
		heroList = self.lineup[self.lineupIdx].hero_list;
	else
		force = 0;
		heroList = {};
	end
	self.defenderItem:setForce(force);

    if self.enemyLineupPanel == nil then
        self.enemyLineupPanel = Lua_HeroGridViewPanel.new(self.content);
        self.enemyLineupPanel:setRectAnchor(1);
        self.enemyLineupPanel:setLocation(204, -209, 0);
        self.enemyLineupPanel:setCanClick(true);
        self.enemyLineupPanel:setLayout(1, 2);
        self.enemyLineupPanel:setGridCell(75, 75);
    end
    if self.player_id == 0 then
	    self.enemyLineupPanel:setDataByProto(heroList, 1);
	else
		self.enemyLineupPanel:setDataByProto(heroList, 3);
	end
end

function Lua_WildLodeAttackLineupWindow:onFightCheck(msg)
	if msg.type == 0 then
		self:onSureFight();
	else
		if msg.type == 1 then
			OperateAlert.showLangValue(701085);
		elseif msg.type == 2 then
			OperateAlert.showLangValue(701050);
		elseif msg.type == 3 then
			OperateAlert.showLangValue(701056);
		end
		self:hide();
	end
end

function Lua_WildLodeAttackLineupWindow:onFight()
	if self.template_id == Lua_FightDefine.TEMPLATE_ID_WILD_PVP_1 then
		Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeFightCheck(self.stage_id, self.player_id, 1);
	else
		Lua_ProxyManager.getProxy("Lua_WildSecretProxy"):sLodeFightCheck(self.stage_id, self.player_id, 2);
	end
end

function Lua_WildLodeAttackLineupWindow:onSureFight()
	if self:checkIsChange() then
		self:onSaveLineup()
	end

	if self.replaceNum == nil then
		Lua_ProxyManager.getProxy("Lua_FightProxy"):sStartFight(self.template_id, self.stage_id);
	else
		Lua_ProxyManager.getProxy("Lua_FightProxy"):sStartFight(self.template_id, self.stage_id, 0, 0, self.replaceNum);
	end
	self.onFightTime = getTime();
end